@@ -74,10 +74,6 @@ class ckbytelist(PyKCS11.LowLevel.ckbytelist):
     def __init__(self, data=[]):
         # default size of the vector
         size = 0
-        if isinstance(data, int):
-            size = data
-            data = None
-
         super(ckbytelist, self).__init__(size)
 
         # No value to initialize
@@ -205,6 +201,8 @@ class CkClass(object):
         for field in self.fields.keys():
             if field == "flags":
                 dico[field] = self.flags2text()
+            elif field == "state":
+                dico[field] = self.state2text()
             else:
                 dico[field] = eval("self." + field)
         return dico
@@ -492,7 +490,8 @@ class PyKCS11Lib(object):
         @param pin: SO's initial PIN
         @param label: new label of the token
         """
-        rv = self.lib.C_InitToken(slot, pin, label)
+        pin1 = ckbytelist(pin)
+        rv = self.lib.C_InitToken(slot, pin1, label)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
 
@@ -767,20 +766,21 @@ class RSAOAEPMechanism(object):
 class RSA_PSS_Mechanism(object):
     """RSA PSS Wrapping mechanism"""
 
-    def __init__(self, hashAlg, mgf, sLen):
+    def __init__(self, mecha, hashAlg, mgf, sLen):
         """
+        @param mecha: the mechanism to use (like CKM_SHA384_RSA_PKCS_PSS)
         @param hashAlg: the hash algorithm to use (like CKM_SHA384)
         @param mgf: the mask generation function to use (like
         CKG_MGF1_SHA384)
         @param sLen: length, in bytes, of the salt value used in the PSS
-        encoding
+        encoding (like 0 or the message length)
         """
         self._param = PyKCS11.LowLevel.CK_RSA_PKCS_PSS_PARAMS()
         self._param.hashAlg = hashAlg
         self._param.mgf = mgf
         self._param.sLen = sLen
         self._mech = PyKCS11.LowLevel.CK_MECHANISM()
-        self._mech.mechanism = CKM_RSA_PKCS_PSS
+        self._mech.mechanism = mecha
         self._mech.pParameter = self._param
         self._mech.ulParameterLen = PyKCS11.LowLevel.CK_RSA_PKCS_PSS_PARAMS_LENGTH
 
@@ -903,7 +903,8 @@ class Session(object):
         CKU_USER. You may also use CKU_SO
         @type user_type: integer
         """
-        rv = self.lib.C_Login(self.session, user_type, pin)
+        pin1 = ckbytelist(pin)
+        rv = self.lib.C_Login(self.session, user_type, pin1)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
 
@@ -923,7 +924,8 @@ class Session(object):
 
         @param new_pin: new PIN
         """
-        rv = self.lib.C_InitPIN(self.session, new_pin)
+        new_pin1 = ckbytelist(pin)
+        rv = self.lib.C_InitPIN(self.session, new_pin1)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
 
@@ -934,7 +936,9 @@ class Session(object):
         @param old_pin: old PIN
         @param new_pin: new PIN
         """
-        rv = self.lib.C_SetPIN(self.session, old_pin, new_pin)
+        old_pin1 = ckbytelist(old_pin)
+        new_pin1 = ckbytelist(new_pin)
+        rv = self.lib.C_SetPIN(self.session, old_pin1, new_pin1)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
 
@@ -1505,7 +1509,7 @@ class Session(object):
         or, for Python 2::
             ''.join(chr(i) for i in random)
         """
-        low_rand = ckbytelist(size)
+        low_rand = ckbytelist([0] * size)
         rv = self.lib.C_GenerateRandom(self.session, low_rand)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
